@@ -3,4 +3,4 @@ __author__ = 'ocarrere'
 from .call import DeferredCallHandler
 from .queue import EventQueue, Event
 from .state import state
-from .state import ValidationError as StateValidationError
\ No newline at end of file
+from .state import StateValidationError
\ No newline at end of file
